import { Rule, Tree } from '@angular-devkit/schematics';
import { LfComponentSchematic } from './schema';
export declare function lfComponentSchematic(_options: LfComponentSchematic): Rule;
/**
 * 1 - Fill the [ngGenerateFatherCompJSON] variable with the ng configs
 * 2 - Creates the ng command that will generate the father(collection)
 * 3 - Add both the rules created to the array of rules
 * @param rules - array of rules used in the schematic
 * @param componentPath - path of the child component
 */
export declare function addFatherCompNgGenerateToRules(rules: Rule[], project: string | undefined, componentPath: string): Rule[];
/**
 * Creates a default Lf-Component based on a element already created by the ng
 * new component command. It is assumed that the app has the angular module
 * activated and that the styles have .scss extension
 * @param tree - app file tree
 * @param compFullPath - full path to new component
 * @param tableBaseElem - [true] if the component being created is a table base element.
 * or [false] if it is simply a component nested inside another.
 */
export declare function createLfComponent(tree: Tree, compFullPath: string, listElemComp: boolean): void;
/**
 * Modifies the listComp(father) if it doesn't modify already and a
 * listElemComp(child) elemenents to be normal Lf-Components
 * (using RecordSchema) and after that modifies the father element to be
 * tableSchema and the child Html and .component.ts file to include the indexs
 * associated to the table. The app.roputing module it's modified to to include
 * the indexes in the new paths created;
 * @param tree - application file tree
 * @param childFullPath - full path to the child component
 */
export declare function createLfCollection(tree: Tree, childFullPath: string): void;
/**
 * Given a component folder path check if the element is a Lf-Component, this is
 * determine by the existance of a .schema.ts file in the component folder
 * @param tree - project file tree
 * @param compFolderPath - path to the component folder
 */
export declare function existsComp(tree: Tree, compFolderPath: string): boolean;
/**
 * Generate the ng generate component configuration json
 * this guarantes the atomicity of all the schematic.
 * @param componentPath - new component full path
 */
export declare function createNgCommandConfig(componentPath: string, project: string | undefined): Rule;
/**
 * Modifies the component in the given path from RecordSchema to TableSchema
 * @param tree - application file tree
 * @param fatherFullPath - full path to the father component
 */
export declare function modifyFatherRecordSchemaToTableSchema(tree: Tree, fatherFullPath: string): void;
/**
 * Creates a component base translation (label) in all the i18n files of all the
 * component idioms. There are two types of labels, one assinged to
 * tableElements and another one for normal components. If it is a table element
 * we are processing the label will the component name followed by the global index.
 * Otherwise is simply the name of the new component.
 * @param tree - project file tree.
 * @param langs - all langs present in the app.i18n.ts file.
 * @param compFullPath - component folder full path.
 * @param compName - component name.
 */
export declare function addCompBaseTranslation(tree: Tree, langs: string[], compFullPath: string, compName: string, listElemComp: boolean): void;
/**
 * Modifies the componet html path that will be used later by the angular
 * routing module. First this method will get the path present in the component
 * in with the current element is nested and will later add the component name
 * or the {{ currElemId()}} depending if we are processing a table element
 * componente or component nested inside a table element
 * @param tree - project file tree
 * @param childFolderPath - component path
 * @param camelCaseChildCompName - component name
 * @param listBaseElement - [true] if the current element is a listElement or
 * [false] if the current element is nested inside a  listElement
 */
export declare function modifyListElementHtml(tree: Tree, childFolderPath: string, camelCaseChildCompName: string): void;
/**
 * This method goes in a cicle of search in the upper directories for a schema
 * file.
 * @param compFolderPath - path the component folder being generated
 * @param tree - project file tree
 */
export declare function getFatherHtmlFilePath(tree: Tree, componentPath: string): string;
/**
 * Modifies the .component.ts file of the component being generated. First this
 * method gets the html path from the component it is nested in. After that it
 * will identify path parts with indexs on it and will import
 * all the index necessary for the child path generation
 * @param tree - project file tree
 * @param childForderPath - new component folder path
 * @param childCompName - new component name
 */
export declare function modifyListElementComponentFile(tree: Tree, childForderPath: string, childCompName: string): void;
/**
 * Modifies the .component.ts file of the component being generated. First this
 * method gets the html path from the component it is nested in. After that it
 * will identify detect path parts of the path depend on indexs and will import
 * all the index necessary for the child path generation
 * @param tree - project file tree
 * @param compFolderPath - component folder path
 * @param compName - component name in camelCase
 */
export declare function includeIndexInComp(tree: Tree, compFolderPath: string, compName: string): void;
/**
 * This constructs the computed indexes declarations that will label be inserted
 * in a .component.ts. It first gets the father component path in html file
 * and iterates over all the deteted indexs to contruct a string with all the declarations
 * @param tree - project file tree
 * @param childForderPath - new component folder path
 */
export declare function includeIndexesInFatherCompHtmlPath(tree: Tree, childForderPath: string): string;
/**
 * Given a index id generates the declaration variable that will later be used
 * to generate a string will all the imports
 * @param indexName - index variable name
 */
export declare function getComputedIndexDeclaration(indexName: string): string;
/**
 * Declares the new component in the app-routing-modules files. The path of the
 * new route will be the full path except the last dir fragment. For example:
 * reservationDetails/accomodation will generate
 * {
 *  path: 'reservation-details',
 *   children: [
 *     {path: 'accomodation', component: AccomodationComponent},
 *  ],
 * },
 * @param tree - app file tree
 * @param compFullPath - new component full path
 * @param compName - componente name
 */
export declare function declareElemInAppRoutingModule(tree: Tree, compFullPath: string, compName: string): void;
/**
 * Puts the attribute change detection to OnPush
 * @param tree - project file tree
 * @param fullPath - path given in the command argument in fileFormat
 * @param compName - new component name
 */
export declare function changeDetectionToOnPush(tree: Tree, fullPath: string, compName: string): void;
/**
 * Modifies the html content of the new file to contain mobxAutorun and lf-form
 * with the respective path used by the angular routing
 * @param tree - project file tree
 * @param fullPath - path given in the command argument in fileFormat
 * @param compName - new component name
 */
export declare function modifyHtmlFile(tree: Tree, fullPath: string, compName: string): void;
/**
 * Returns the new content of the html file of the new component
 * @param fatherCompHtmlRoutePath  - component html path
 * @param compName - component name
 */
export declare function generateHtmlNewContent(fatherCompHtmlRoutePath: string, compName: string): string;
/**
 * Retrieves the path on the html fil of the component in witch the new
 * component is nested in.
 * @param tree - project file tree.
 * @param fullPath - new component full path.
 */
export declare function getFatherCompHtmlPath(tree: Tree, fullPath: string): string;
/**
 * Given a component folder path retirves the path of the element present in the
 * componen.html file
 * @param tree - project file tree
 * @param compFolderPath - path to the compoenent folder
 */
export declare function getCompHtmlPath(tree: Tree, compFolderPath: string): string;
/**
 * Method that declares the new compName i18n file with lang extension in the
 * app.[langs] file.
 * @param tree - project file tree
 * @param langs - langs extensions of the files to be declared
 * @param compName - name of th new component
 * @param compFullPath - path given in the schematic arguments except the last /[componentName]
 */
export declare function declareI18NFilesInApp(tree: Tree, langs: string[], compName: string, compFullPath: string): number;
/**
 * Given the path where the new component will be inserted, declares the new component
 * schema in the father component schema
 * @param tree - project fpath where the new component will be insertedile tree
 * @param inicialPath - path where the new component will be inserted
 */
export declare function declareNewCompSchemaInFatherComp(tree: Tree, inicialPath: string, compCamelCase: string): import("@angular-devkit/schematics/src/tree/interface").Tree;
/**
 * This method goes in a cicle of search in the upper directories for a schema
 * file.
 * @param compFolderPath - path the component folder being generated
 * @param tree - project file tree
 */
export declare function getFatherSchemaFilePath(tree: Tree, componentPath: string): string;
/**
 * Given the new component name and this father component, declares the child
 * schema in the father schema
 * @param newComponent - new component name
 * @param fatherContent - father component name
 * @param tree - schametic tree
 */
export declare function declareChildSchemaInFatherSchema(childCompPath: string, compCamelCase: string, fatherContent: string, fatherSchemaFile: string, tree: Tree): void;
/**
 * Generate all the I18N files bases of the entries of lang, if all the
 * elementes in the array respect the for xx.XX creates a file for each one with
 * the correspondent extensions and returns the number of files created. It
 * returns -1 if there is an error in any of the files.
 * @param tree - project file tree
 * @param inicialPath - path where the nem element will be created
 * @param compFileSystemName - element name in file system format
 * @param compName - component name in camel case
 * @param langs - array of idioms to be generated
 */
export declare function generateI18NFile(tree: Tree, inicialPath: string, compFileSystemName: string, compName: string, langs: string[]): number;
/**
 * Retrieves the idioms options to be generated for the new component, if
 * none is defined an execption is thrown
 * @param tree - project files tree
 */
export declare function getIdiomsFromAppI18nFile(tree: Tree): string[];
/**
 * Given the new component name generates the correspondent schema file
 * @param component - component name
 */
export declare function schemaFileContent(component: string): string;
/**
 * Given the new component name and the idiom of the translation generates the correspondent I18N file
 * @param component - component name
 * @param lang - idiom of the I18N file
 */
export declare function langFileContent(component: string, lang: string): string;
